@@ -1,10 +1,31 @@
+#
+#   xts: eXtensible time-series
+#
+#   Copyright (C) 2008  Jeffrey A. Ryan jeff.a.ryan @ gmail.com
+#
+#   Contributions from Joshua M. Ulrich
+#
+#   This program is free software: you can redistribute it and/or modify
+#   it under the terms of the GNU General Public License as published by
+#   the Free Software Foundation, either version 2 of the License, or
+#   (at your option) any later version.
+#
+#   This program is distributed in the hope that it will be useful,
+#   but WITHOUT ANY WARRANTY; without even the implied warranty of
+#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#   GNU General Public License for more details.
+#
+#   You should have received a copy of the GNU General Public License
+#   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+
 align.time <- function(x, ...) {
   UseMethod("align.time")
 }
 
 align.time.xts <- function(x, n=60, ...) {
   if(n <= 0) stop("'n' must be positive")
-  .xts(x, .index(x) + (n-.index(x) %% n), tzone=indexTZ(x), tclass=indexClass(x))
+  .xts(x, .index(x) + (n-.index(x) %% n), tzone=tzone(x), tclass=tclass(x))
 }
 
 align.time.POSIXct <- function(x, n=60, ...) {
@@ -22,7 +43,7 @@ shift.time <- function(x, n=60, ...) {
 }
 
 shift.time.xts <- function(x, n=60, ...) {
-  .xts(x, .index(x) + n, tzone=indexTZ(x), tclass=indexClass(x))
+  .xts(x, .index(x) + n, tzone=tzone(x), tclass=tclass(x))
 }
 
 is.index.unique <- is.time.unique <- function(x) {
