@@ -31,22 +31,5 @@ function(x) {
 
 `dimnames<-.xts` <-
 function(x, value) {
-  oclass <- class(x)
-  x <- unclass(x)
-
-  if(is.null(value)) {
-    dimnames(x) <- NULL
-    class(x) <- oclass
-  }
-  else {
-    if(!is.list(value) || length(value) != 2L)
-      stop("invalid 'dimnames' given for xts")
-    value[[1L]] <- list(NULL)
-    value[[2L]] <- as.character(value[[2L]])
-  
-    rownames(x) <- NULL
-    colnames(x) <- value[[2L]]
-    class(x) <- oclass
-  }
-  x
+  .Call("xts_set_dimnames", x, value, PACKAGE = "xts")
 }
