@@ -1,3 +1,24 @@
+#
+#   xts: eXtensible time-series
+#
+#   Copyright (C) 2008  Jeffrey A. Ryan jeff.a.ryan @ gmail.com
+#
+#   Contributions from Joshua M. Ulrich
+#
+#   This program is free software: you can redistribute it and/or modify
+#   it under the terms of the GNU General Public License as published by
+#   the Free Software Foundation, either version 2 of the License, or
+#   (at your option) any later version.
+#
+#   This program is distributed in the hope that it will be useful,
+#   but WITHOUT ANY WARRANTY; without even the implied warranty of
+#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#   GNU General Public License for more details.
+#
+#   You should have received a copy of the GNU General Public License
+#   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+
 # This function corresponds to the ISO 8601 standard
 # for specifying dates and times as described in
 # the ISO 8601:2004e standard.
@@ -95,7 +116,7 @@
    # return as list
    c(as.list(c(
      year=as_numeric(YYYY),
-     mon=as_numeric(MM),
+     month=as_numeric(MM),
      day=as_numeric(DD),
      hour=as_numeric(H),
      min=as_numeric(M),
@@ -112,6 +133,10 @@
    if(is.na(e))
      e <- as.POSIXlt(do.call(lastof,  parse.side(intervals[2])))
  }
+ if(is.na(s) && is.na(e) && !nzchar(DURATION) && intervals[1L] != "") {
+   warning("cannot determine first and last time from ", x)
+   return(list(first.time=NA_real_,last.time=NA_real_))
+ }
  if(!missing(start)) {
    start <- as.numeric(start)
    #s <- as.POSIXlt(structure(max(start, as.numeric(s), na.rm=TRUE),
@@ -152,25 +177,3 @@
 
  list(first.time=as.POSIXct(s),last.time=as.POSIXct(e))
 }
-
-.makeISO8601TT <- function(x, from, to) {
-  # parse T08:30/T15:00 queries across all
-  # available days into a vector of character
-  # strings compatible with the xts/ISO8601
-  # subsetting.  Thanks to Brian Peterson for
-  # the challenge ;-)
-  ep <- endpoints(x, on='days')
-  start_of <- (ep+1)[-length(ep)]
-  end_of   <- ep[-1]
-  if(as.numeric(from) < as.numeric(to)) {
-    paste(format(index(x[start_of]),paste("%Y%m%d",from,sep="T")),
-          format(index(x[end_of  ]),paste("%Y%m%d",to  ,sep="T")),sep="/")
-  } else {
-    c(
-    paste(format(index(x[start_of]),"%Y%m%d"),
-          format(index(x[end_of  ]),paste("%Y%m%d",to  ,sep="T")),sep="/"),
-    paste(format(index(x[start_of]),paste("%Y%m%d",from,sep="T")),
-          format(index(x[end_of  ]),"%Y%m%d"),sep="/")
-    )
-  }
-}
