@@ -108,8 +108,6 @@ if(TYPEOF(xindex)==INTSXP) {
   PROTECT(newindex = allocVector(TYPEOF(xindex), len)); P++;
   PROTECT(result   = allocVector(TYPEOF(x), len * ncx)); P++;
 
-  copyMostAttrib(xindex, newindex);
-
   switch( TYPEOF(x) ) {
     case INTSXP:
         int_x = INTEGER(x);
@@ -498,10 +496,9 @@ return(result);
   if(truelen != len) {
     PROTECT(newindex = lengthgets(newindex, truelen)); P++;
   }
+  copyMostAttrib(xindex, newindex);
+
   setAttrib(result, xts_IndexSymbol, newindex);
-  setAttrib(result, xts_IndexClassSymbol, getAttrib(x, xts_IndexClassSymbol));
-  setAttrib(result, xts_IndexTZSymbol, getAttrib(x, xts_IndexTZSymbol));
-  setAttrib(result, xts_IndexFormatSymbol, getAttrib(x, xts_IndexFormatSymbol));
   setAttrib(result, xts_ClassSymbol, getAttrib(x, xts_ClassSymbol));
   copy_xtsAttributes(x, result);
   UNPROTECT(P);
